from distutils.core import setup


setup(
    name = 'gcharts',
    packages = ['gcharts'],
    version = '0.1.0',
    description = 'Python wrapper for Google Charts',
    author = 'Guillermo Guirao Aguilar',
    author_email = 'contact@guillermoguiraoaguilar.com',
    url = 'https://github.com/Funk66/gcharts.git',
    keywords = ['google', 'charts']
)
